@@ -27,24 +27,21 @@
 import os
 from hashlib import sha512
 from slapos.recipe.librecipe import GenericBaseRecipe
+from slapos.util import str2bytes
 
 class Recipe(GenericBaseRecipe):
 
   def install(self):
     options = self.options
-    script = self.createWrapper(name=options['wrapper'],
-                                command=options['server-binary'],
-                                parameters=[
+    # Script that execute the callback(s) upon receiving a notification.
+    return self.createWrapper(options['wrapper'],
+                                (options['server-binary'],
                                    '--callbacks', options['callbacks'],
                                    '--feeds', options['feeds'],
                                    '--equeue-socket', options['equeue-socket'],
                                    options['host'], options['port']
-                                   ],
-                                comments=[
-                                    '',
-                                    'Upon receiving a notification, execute the callback(s).',
-                                    ''])
-    return [script]
+                                   ),
+                                )
 
 
 class Callback(GenericBaseRecipe):
@@ -53,7 +50,7 @@ class Callback(GenericBaseRecipe):
     # XXX: hashing the name here and in
     # slapos.toolbox/slapos/pubsub/__init__.py is completely messed up and
     # prevent any debug.
-    callback_id = sha512(notification_id).hexdigest()
+    callback_id = sha512(str2bytes(notification_id)).hexdigest()
 
     filepath = os.path.join(self.options['callbacks'], callback_id)
     self.addLineToFile(filepath, callback)
@@ -66,31 +63,46 @@ class Callback(GenericBaseRecipe):
 
 class Notify(GenericBaseRecipe):
 
+  def __init__(self, buildout, name, options):
+    super(Notify, self).__init__(buildout, name, options)
+    log = os.path.join(options['feeds'], options['name'])
+    options['log-file'] = log
+    self.options = options
+
   def createNotifier(self, notifier_binary, wrapper, executable,
-                     log, title, notification_url, feed_url, pidfile=None):
+                     log, title, notification_url, feed_url, max_run='1', pidfile=None,
+                     instance_root_name=None, log_url=None, status_item_directory=None):
 
     if not os.path.exists(log):
       # Just a touch
       open(log, 'w').close()
 
-    parameters = [
+    cmd = [notifier_binary,
             '-l', log,
             '--title', title,
             '--feed', feed_url,
+            '--max-run', str(max_run),
             '--notification-url',
             ]
-    parameters.extend(notification_url.split(' '))
-    parameters.extend(['--executable', executable])
+    cmd += notification_url.split(' ')
+    cmd += '--executable', executable
+    # For a more verbose mode, writing feed items for any action
+    instance_root_name = instance_root_name or self.options.get('instance-root-name', None)
+    log_url = log_url or self.options.get('log-url', None)
+    status_item_directory = status_item_directory or self.options.get('status-item-directory', None)
+    if instance_root_name and log_url and status_item_directory:
+      cmd += (
+        '--instance-root-name', instance_root_name,
+        '--log-url', log_url,
+        '--status-item-directory', status_item_directory,
+      )
 
-    return self.createWrapper(name=wrapper,
-                              command=notifier_binary,
-                              parameters=parameters,
-                              pidfile=pidfile,
-                              parameters_extra=True,
-                              comments=[
-                                  '',
-                                  'Call an executable and send notification(s).',
-                                  ''])
+    kw = {}
+    if pidfile:
+      kw['pidfile'] = pidfile
+
+    # Script that call an executable and send notification(s).
+    return self.createWrapper(wrapper, cmd, **kw)
 
 
   def install(self):
@@ -98,15 +110,14 @@ class Notify(GenericBaseRecipe):
                                port=self.options['port'],
                                path='/get/%s' % self.options['name'])
 
-    log = os.path.join(self.options['feeds'], self.options['name'])
-
     options = self.options
     script = self.createNotifier(notifier_binary=options['notifier-binary'],
                                  wrapper=options['wrapper'],
                                  executable=options['executable'],
-                                 log=log,
+                                 log=options['log-file'],
                                  title=options['title'],
                                  pidfile=options['pidfile'],
                                  notification_url=options['notify'],
-                                 feed_url=feed_url)
+                                 feed_url=feed_url,
+                                 max_run=options.get('max-run', "1"))
     return [script]
