@@ -38,7 +38,7 @@ class Recipe(GenericBaseRecipe):
     :param lines hash-files: list of buildout-generated files to be checked by hash
     :param lines hash-existing-files: list of existing files to be checked by hash
     :param str pidfile: path to pidfile ensure exclusivity for the process
-    :param str private-dev-shm: size of private /dev/shm, using user namespaces
+    :param lines private-tmpfs: list of "<size> <path>" private tmpfs, using user namespaces
     :param bool reserve-cpu: command will ask for an exclusive CPU core
     """
 
@@ -72,13 +72,17 @@ class Recipe(GenericBaseRecipe):
           raise UserError(
             "hash-files must only list files that are generated by buildout:"
             "\n  " + "\n  ".join(self._existing))
-        args = shlex.split(self.options['command-line'])
-        wait_files = self.options.get('wait-for-files')
-        pidfile = self.options.get('pidfile')
-        private_dev_shm = self.options.get('private-dev-shm')
+        options = self.options
+        args = shlex.split(options['command-line'])
+        wait_files = options.get('wait-for-files')
+        pidfile = options.get('pidfile')
+        private_tmpfs = self.parsePrivateTmpfs()
+        private_dev_shm = options.get('private-dev-shm') # BBB
+        if private_dev_shm:
+          private_tmpfs.append((private_dev_shm, '/dev/shm'))
 
         environment = {}
-        for line in (self.options.get('environment') or '').splitlines():
+        for line in (options.get('environment') or '').splitlines():
           line = line.strip()
           if line:
             k, v = line.split('=', 1)
@@ -89,9 +93,9 @@ class Recipe(GenericBaseRecipe):
           kw['wait_list'] = wait_files.split()
         if pidfile:
           kw['pidfile'] = pidfile
-        if private_dev_shm:
-          kw['private_dev_shm'] = private_dev_shm
-        if self.isTrueValue(self.options.get('reserve-cpu')):
+        if private_tmpfs:
+          kw['private_tmpfs'] = private_tmpfs
+        if self.isTrueValue(options.get('reserve-cpu')):
           kw['reserve_cpu'] = True
         return self.createWrapper(self.getWrapperPath(),
                                   args, environment, **kw)
